MSK Seg Util
============

A Python package for MSK segmentation and anaylsis utilities.

Installation
------------

Pystats requires Python version >= 3.6.

Via ``conda``
*************

We recommend installing Pystats through ``conda``::

    conda install -c arjundd msk_seg_util
    # (required for statistics) pip install scikit-posthocs
    # (required for segmentation metrics) pip install medpy
    # (required for visualization) pip install opencv-python
